{% load url from future %}
{% load i18n %}

{% if HORIZON_CONFIG.system_module and request.user.is_superuser %}
<div class="btn-group btn-group-justified" style='margin-top: 5px;'>
  <a href="{% url 'server_reload' %}" title="{% trans 'Reload server' %}" class="ajax-modal btn btn-default hidden-xs">
    <span class="glyphicon glyphicon-refresh"></span>
  </a>
  <a href="{% url 'system_info' %}" title="{% trans 'System Info' %}" class="ajax-modal btn btn-default hidden-xs">
    <span class="glyphicon glyphicon-info-sign"></span>
  </a>
  <a href="{% url 'plugin_install' %}" title="{% trans 'Install Plugins' %}" class="ajax-modal btn btn-default hidden-xs">
    <span class="glyphicon glyphicon-plus"></span>
  </a>
  <a href="{% url 'server_management' %}" title="{% trans 'Management commands' %}" class="ajax-modal btn btn-default hidden-xs">
    <span class="glyphicon glyphicon-cog"></span>
  </a>
</div>
{% endif %}